@@ -22,9 +22,15 @@
 #ifndef __qjackctlAbout_h
 #define __qjackctlAbout_h
 
-#define QJACKCTL_TITLE      "JACK Audio Connection Kit"
-#define QJACKCTL_SUBTITLE   "Qt GUI Interface"
-#define QJACKCTL_VERSION    "0.2.18"
+#include "config.h"
+
+#define QJACKCTL_TITLE      PACKAGE_NAME
+#define QJACKCTL_VERSION    PACKAGE_VERSION
+
+#define QJACKCTL_SUBTITLE1  "JACK Audio Connection Kit"
+#define QJACKCTL_SUBTITLE2  "Qt GUI Interface"
+
+#define QJACKCTL_SUBTITLE   QJACKCTL_SUBTITLE1 " - " QJACKCTL_SUBTITLE2
 #define QJACKCTL_WEBSITE    "http://qjackctl.sourceforge.net"
 #define QJACKCTL_COPYRIGHT  "Copyright (C) 2003-2005, rncbc aka Rui Nuno Capela. All rights reserved."
 
