@@ -1,7 +1,7 @@
 // qjackctlJackConnect.h
 //
 /****************************************************************************
-   Copyright (C) 2003, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2005, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -59,9 +59,6 @@ public:
     jack_client_t *jackClient();
     jack_port_t   *jackPort();
 
-    // Special port name sorting virtual comparator.
-    virtual int compare (QListViewItem* pPortItem, int iColumn, bool bAscending) const;
-
 private:
 
     // Instance variables.
