@@ -20,6 +20,11 @@
 
 *****************************************************************************/
 
+#include "qjackctlAbout.h"
+#include "qjackctlStatus.h"
+
+#include "qjackctlPatchbayFile.h"
+
 #include <qapplication.h>
 #include <qobjectlist.h>
 #include <qeventloop.h>
@@ -27,13 +32,6 @@
 #include <qregexp.h>
 #include <qtimer.h>
 
-#include "config.h"
-
-#include "qjackctlStatus.h"
-#include "qjackctlAbout.h"
-
-#include "qjackctlPatchbayFile.h"
-
 #ifdef HAVE_POLL_H
 #include <poll.h>
 #endif
@@ -183,7 +181,8 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
     m_pConnectionsForm = new qjackctlConnectionsForm (this, 0, wflags);
     m_pPatchbayForm    = new qjackctlPatchbayForm    (this, 0, wflags);
 	// Setup appropriately...
-	m_pConnectionsForm->setupAliases(m_pSetup);
+	m_pConnectionsForm->setup(m_pSetup);
+	m_pPatchbayForm->setup(m_pSetup);
 
     // Set the patchbay cable connection notification signal/slot.
     QObject::connect(&m_patchbayRack, SIGNAL(cableConnected(const QString&, const QString&, unsigned int)),
@@ -266,10 +265,13 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
     }
 #endif
 
-    // Load patchbay from default path.
-    if (m_pPatchbayForm && !m_pSetup->sPatchbayPath.isEmpty())
-        m_pPatchbayForm->loadPatchbayFile(m_pSetup->sPatchbayPath);
-
+    // Load patchbay form recent paths...
+    if (m_pPatchbayForm) {
+		m_pPatchbayForm->setRecentPatchbays(m_pSetup->patchbays);
+	 	if (!m_pSetup->sPatchbayPath.isEmpty())
+        	m_pPatchbayForm->loadPatchbayFile(m_pSetup->sPatchbayPath);
+	}
+	
     // Try to find if we can start in detached mode (client-only)
     // just in case there's a JACK server already running.
     startJackClient(true);
@@ -306,7 +308,8 @@ bool qjackctlMainForm::queryClose (void)
 
     // Check if JACK daemon is currently running...
     if (bQueryClose && m_pJack && m_pJack->isRunning() && m_pSetup->bQueryClose) {
-        switch (QMessageBox::warning(this, tr("Warning"),
+        switch (QMessageBox::warning(this,
+			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
             tr("JACK is currently running.") + "\n\n" +
             tr("Do you want to terminate the JACK audio server?"),
             tr("Terminate"), tr("Leave"), tr("Cancel"))) {
@@ -450,7 +453,8 @@ void qjackctlMainForm::startJack (void)
 
     // Is the server process instance still here?
     if (m_pJack) {
-        switch (QMessageBox::warning(this, tr("Warning"),
+        switch (QMessageBox::warning(this,
+			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
             tr("Could not start JACK.") + "\n\n" +
             tr("Maybe JACK audio server is already started."),
             tr("Stop"), tr("Kill"), tr("Cancel"))) {
@@ -546,12 +550,16 @@ void qjackctlMainForm::startJack (void)
     bool bPortaudio = (m_preset.sDriver == "portaudio");
 	bool bCoreaudio = (m_preset.sDriver == "coreaudio");
     if (bAlsa && (m_preset.iAudio != QJACKCTL_DUPLEX ||
-		m_preset.sInDevice.isEmpty() || m_preset.sOutDevice.isEmpty()))
-        m_pJack->addArgument("-d" + m_preset.sInterface);
+		m_preset.sInDevice.isEmpty() || m_preset.sOutDevice.isEmpty())) {
+		QString sInterface = m_preset.sInterface;
+		if (sInterface.isEmpty())
+			sInterface = "hw:0";
+        m_pJack->addArgument("-d" + sInterface);
+	}
     if (bPortaudio && m_preset.iChan > 0)
         m_pJack->addArgument("-c" + QString::number(m_preset.iChan));
-	if (bCoreaudio)
-		m_pJack->addArgument("-n" + QString::number(m_preset.sInterface.toInt()));
+    if (bCoreaudio && !m_preset.sInterface.isEmpty())
+	    m_pJack->addArgument("-n" + m_preset.sInterface);
     if (m_preset.iSampleRate > 0)
         m_pJack->addArgument("-r" + QString::number(m_preset.iSampleRate));
     if (m_preset.iFrames > 0)
@@ -583,14 +591,18 @@ void qjackctlMainForm::startJack (void)
             m_pJack->addArgument("-m");
         if (m_preset.bShorts)
             m_pJack->addArgument("-S");
-    }
-	if (bAlsa || bCoreaudio) {
 		if (m_preset.iInChannels > 0  && m_preset.iAudio != QJACKCTL_PLAYBACK)
 			m_pJack->addArgument("-i" + QString::number(m_preset.iInChannels));
 		if (m_preset.iOutChannels > 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
 			m_pJack->addArgument("-o" + QString::number(m_preset.iOutChannels));
+    }
+	else if (bCoreaudio) {
+		if (m_preset.iInChannels >= 0  && m_preset.iAudio != QJACKCTL_PLAYBACK)
+			m_pJack->addArgument("-i" + QString::number(m_preset.iInChannels));
+		if (m_preset.iOutChannels >= 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
+			m_pJack->addArgument("-o" + QString::number(m_preset.iOutChannels));
 	}
-    if (bOss) {
+    else if (bOss) {
         if (m_preset.bIgnoreHW)
             m_pJack->addArgument("-b");
         if (m_preset.iWordLength > 0)
@@ -683,7 +695,8 @@ void qjackctlMainForm::stopJack (void)
 	if (m_pSetup->bQueryShutdown
 		&& m_pJack && m_pJack->isRunning() && !m_bJackSurvive
 		&& m_pConnectionsForm && m_pConnectionsForm->isJackConnected()
-		&& QMessageBox::warning(this, tr("Warning"),
+		&& QMessageBox::warning(this,
+			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
 			tr("Some client audio applications") + "\n" +
 			tr("are still active and connected.") + "\n\n" +
 			tr("Do you want to stop the JACK audio server?"),
@@ -881,7 +894,8 @@ void qjackctlMainForm::appendMessagesError( const QString& s )
 
     appendMessagesColor(s.simplifyWhiteSpace(), "#ff0000");
 
-    QMessageBox::critical(this, tr("Error"), s, tr("Cancel"));
+    QMessageBox::critical(this,
+		tr("Error") + " - " QJACKCTL_SUBTITLE1, s, tr("Cancel"));
 }
 
 
@@ -1098,24 +1112,28 @@ void qjackctlMainForm::updateActivePatchbay (void)
 }
 
 // Toggle active patchbay setting.
-void qjackctlMainForm::toggleActivePatchbay ( const QString& sPatchbayPath )
+void qjackctlMainForm::setActivePatchbay ( const QString& sPatchbayPath )
 {
     if (m_pSetup == NULL)
         return;
         
-    if (!sPatchbayPath.isEmpty()) {
-        // If already exactly active, deactivate it.
-        if (m_pSetup->bActivePatchbay && m_pSetup->sActivePatchbayPath == sPatchbayPath) {
-            m_pSetup->bActivePatchbay = false;
-        } else {
-            m_pSetup->bActivePatchbay = true;
-            m_pSetup->sActivePatchbayPath = sPatchbayPath;
-        }
-    }
+    if (sPatchbayPath.isEmpty()) {
+        m_pSetup->bActivePatchbay = false;
+	} else {
+		m_pSetup->bActivePatchbay = true;
+		m_pSetup->sActivePatchbayPath = sPatchbayPath;
+	}
+
     updateActivePatchbay();
 }
 
 
+// Reset the MRU patchbay list.
+void qjackctlMainForm::setRecentPatchbays ( const QStringList& patchbays )
+{
+	m_pSetup->patchbays = patchbays;
+}
+
 
 // Stabilize current form toggle buttons that may be astray.
 void qjackctlMainForm::stabilizeForm (void)
@@ -1578,8 +1596,11 @@ bool qjackctlMainForm::startJackClient ( bool bDetach )
     QString sClientName = "qjackctl-" + QString::number((int) ::getpid());
     m_pJackClient = jack_client_new(sClientName.latin1());
     if (m_pJackClient == NULL) {
-        if (!bDetach)
-            appendMessagesError(tr("Could not connect to JACK server as client."));
+        if (!bDetach) {
+            appendMessagesError(
+				tr("Could not connect to JACK server as client.\n\n"
+				"Please check the messages window for more info."));
+		}
         return false;
     }
 
@@ -2178,7 +2199,7 @@ void qjackctlMainForm::updateStatusItem( int iStatusItem, const QString& sText )
 // Main window caption title and system tray icon and tooltip update.
 void qjackctlMainForm::updateTitleStatus (void)
 {
-    QString sTitle = QJACKCTL_TITLE " ";
+    QString sTitle = QJACKCTL_SUBTITLE1 " ";
 
     if (m_pSetup)
         sTitle += "[" + m_pSetup->sDefPreset + "] ";
@@ -2373,7 +2394,8 @@ void qjackctlMainForm::showDirtySettingsWarning (void)
     // If client service is currently running,
     // prompt the effective warning...
     if (m_pJackClient) {
-        QMessageBox::warning(this, tr("Warning"),
+        QMessageBox::warning(this,
+			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
             tr("Server settings will be only effective after\n"
                "restarting the JACK audio server."), tr("OK"));
     }   // Otherwise, it will be just as convenient to update status...
@@ -2384,7 +2406,8 @@ void qjackctlMainForm::showDirtySettingsWarning (void)
 // Setup otions change warning.
 void qjackctlMainForm::showDirtySetupWarning (void)
 {
-    QMessageBox::information(this, tr("Information"),
+    QMessageBox::information(this,
+		tr("Information") + " - " QJACKCTL_SUBTITLE1,
         tr("Some settings will be only effective\n"
            "the next time you start this program."), tr("OK"));
 }
