@@ -587,7 +587,7 @@ bool qjackctlSocketList::addSocketItem (void)
 
     qjackctlSocketForm *pSocketForm = new qjackctlSocketForm(m_pListView);
     if (pSocketForm) {
-        pSocketForm->setCaption("<" + tr("New") + "> - " + m_sSocketCaption);
+		pSocketForm->setCaption("<" + tr("New") + "> - " + m_sSocketCaption);
         pSocketForm->setSocketCaption(m_sSocketCaption);
         pSocketForm->setPixmaps(m_apPixmaps);
         pSocketForm->setReadable(m_bReadable);
@@ -628,7 +628,8 @@ bool qjackctlSocketList::removeSocketItem (void)
 
     qjackctlSocketItem *pSocketItem = selectedSocketItem();
     if (pSocketItem) {
-        if (QMessageBox::warning(m_pListView, tr("Warning"),
+        if (QMessageBox::warning(m_pListView,
+			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
             m_sSocketCaption + " " + tr("about to be removed") + ":\n\n" +
             "\"" + pSocketItem->socketName() + "\"\n\n" +
             tr("Are you sure?"),
@@ -652,7 +653,8 @@ bool qjackctlSocketList::editSocketItem (void)
     if (pSocketItem) {
         qjackctlSocketForm *pSocketForm = new qjackctlSocketForm(m_pListView);
         if (pSocketForm) {
-            pSocketForm->setCaption(pSocketItem->socketName() + " - " + m_sSocketCaption);
+			pSocketForm->setCaption(pSocketItem->socketName()
+				+ " - " + m_sSocketCaption);
             pSocketForm->setSocketCaption(m_sSocketCaption);
             pSocketForm->setPixmaps(m_apPixmaps);
             pSocketForm->setReadable(m_bReadable);
@@ -710,7 +712,8 @@ bool qjackctlSocketList::copySocketItem (void)
 			do { sSocketName = sSkel.arg(++iSocketNo); }
 			while (findSocket(sSocketName));
 			// Show up as a new socket...
-            pSocketForm->setCaption(pSocketItem->socketName() + " <" + tr("Copy") + "> - " + m_sSocketCaption);
+			pSocketForm->setCaption(pSocketItem->socketName()
+				+ " <" + tr("Copy") + "> - " + m_sSocketCaption);
             pSocketForm->setSocketCaption(m_sSocketCaption);
             pSocketForm->setPixmaps(m_apPixmaps);
             pSocketForm->setReadable(m_bReadable);
@@ -838,25 +841,27 @@ qjackctlSocketListView::qjackctlSocketListView ( qjackctlPatchbayView *pPatchbay
 
 	m_pToolTip = new qjackctlPatchbayToolTip(this);
 
-    if (bReadable)
-        QListView::addColumn(tr("Output Sockets") + " / " + tr("Plugs"));
-    else
-        QListView::addColumn(tr("Input Sockets") + " / " + tr("Plugs"));
-
     QListView::header()->setClickEnabled(false);
     QListView::header()->setResizeEnabled(false);
-    QListView::setMinimumSize(QSize(152, 60));
+    QListView::setMinimumWidth(120);
     QListView::setAllColumnsShowFocus(true);
+	QListView::setColumnWidthMode(0, QListView::Maximum);
     QListView::setRootIsDecorated(true);
     QListView::setResizeMode(QListView::AllColumns);
     QListView::setAcceptDrops(true);
     QListView::setDragAutoScroll(true);
-    QListView::setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
+	QListView::setSizePolicy(
+		QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
 
     QListView::setSorting(-1);
 
 	QListView::setShowToolTips(false);
 
+    if (bReadable)
+        QListView::addColumn(tr("Output Sockets") + " / " + tr("Plugs"));
+    else
+        QListView::addColumn(tr("Input Sockets") + " / " + tr("Plugs"));
+
     setAutoOpenTimeout(800);
 }
 
@@ -1027,9 +1032,10 @@ qjackctlPatchworkView::qjackctlPatchworkView ( qjackctlPatchbayView *pPatchbayVi
 {
     m_pPatchbayView = pPatchbayView;
 
-    QWidget::setMinimumSize(QSize(22, 60));
+    QWidget::setMinimumWidth(20);
     QWidget::setMaximumWidth(120);
-    QWidget::setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
+	QWidget::setSizePolicy(
+		QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Expanding));
 }
 
 // Default destructor.
@@ -1249,7 +1255,7 @@ void qjackctlPatchbayView::contextMenu ( const QPoint& pos, qjackctlSocketList *
 		tr("&Refresh"), pPatchbay, SLOT(refresh()), tr("Alt+R", "Refresh"));
 
     pContextMenu->exec(pos);
-    
+
     delete pContextMenu;
 }
 
@@ -1571,7 +1577,8 @@ bool qjackctlPatchbay::canDisconnectAll (void)
 // Disconnect all plugs.
 bool qjackctlPatchbay::disconnectAll (void)
 {
-    if (QMessageBox::warning(m_pPatchbayView, tr("Warning"),
+    if (QMessageBox::warning(m_pPatchbayView,
+		tr("Warning") + " - " QJACKCTL_SUBTITLE1,
         tr("This will disconnect all sockets.") + "\n\n" +
         tr("Are you sure?"),
         tr("Yes"), tr("No")) > 0) {
