@@ -19,8 +19,8 @@
 
 *****************************************************************************/
 
-#include "qjackctlSetup.h"
 #include "qjackctlAbout.h"
+#include "qjackctlSetup.h"
 
 #include <qtimer.h>
 
@@ -35,10 +35,10 @@ qjackctlSetup::qjackctlSetup (void)
 
     m_settings.beginGroup("/Presets");
     sDefPreset = m_settings.readEntry("/DefPreset", sDefPresetName);
-    const QString sPrefix = "/Preset";
+    QString sPrefix = "/Preset%1";
     int i = 0;
     for (;;) {
-        QString sItem = m_settings.readEntry(sPrefix + QString::number(++i), QString::null);
+        QString sItem = m_settings.readEntry(sPrefix.arg(++i), QString::null);
         if (sItem.isEmpty())
             break;
         presets.append(sItem);
@@ -74,7 +74,12 @@ qjackctlSetup::qjackctlSetup (void)
     iConnectionsIconSize     = m_settings.readNumEntry("/ConnectionsIconSize", QJACKCTL_ICON_16X16);
     sConnectionsFont         = m_settings.readEntry("/ConnectionsFont", QString::null);
     bQueryClose              = m_settings.readBoolEntry("/QueryClose", true);
+    // hack: default keep on top to false for Macs, because window focus looks bad
+#ifdef __APPLE__
+    bKeepOnTop               = m_settings.readBoolEntry("/KeepOnTop", false);
+#else
     bKeepOnTop               = m_settings.readBoolEntry("/KeepOnTop", true);
+#endif
     bSystemTray              = m_settings.readBoolEntry("/SystemTray", false);
     bDelayedSetup            = m_settings.readBoolEntry("/DelayedSetup", false);
     bServerConfig            = m_settings.readBoolEntry("/ServerConfig", true);
@@ -88,6 +93,18 @@ qjackctlSetup::qjackctlSetup (void)
     m_settings.beginGroup("/Defaults");
     sPatchbayPath = m_settings.readEntry("/PatchbayPath", QString::null);
     m_settings.endGroup();
+
+	// Load recent patchbay list...
+	m_settings.beginGroup("/Patchbays");
+	sPrefix = "/Patchbay%1";
+	i = 0;
+	for (;;) {
+		QString sItem = m_settings.readEntry(sPrefix.arg(++i), QString::null);
+		if (sItem.isEmpty())
+			break;
+		patchbays.append(sItem);
+	}
+	m_settings.endGroup();
 }
 
 
@@ -102,14 +119,15 @@ qjackctlSetup::~qjackctlSetup (void)
     m_settings.beginGroup("/Presets");
     m_settings.writeEntry("/DefPreset", sDefPreset);
     // Save last preset list.
-    const QString sPrefix = "/Preset";
-    int i = 0;
-    for (QStringList::Iterator iter = presets.begin(); iter != presets.end(); iter++)
-        m_settings.writeEntry(sPrefix + QString::number(++i), *iter);
-    // Cleanup old entries, if any...
-    for (++i; !m_settings.readEntry(sPrefix + QString::number(i)).isEmpty(); i++)
-        m_settings.removeEntry(sPrefix + QString::number(i));
-    m_settings.endGroup();
+	QString sPrefix = "/Preset%1";
+	int i = 0;
+	for (QStringList::Iterator iter = presets.begin();
+		iter != presets.end(); iter++)
+	    m_settings.writeEntry(sPrefix.arg(++i), *iter);
+	// Cleanup old entries, if any...
+	for (++i; !m_settings.readEntry(sPrefix.arg(i)).isEmpty(); i++)
+	    m_settings.removeEntry(sPrefix.arg(i));
+	m_settings.endGroup();
 
     m_settings.beginGroup("/Options");
     m_settings.writeEntry("/StartJack",               bStartJack);
@@ -155,6 +173,18 @@ qjackctlSetup::~qjackctlSetup (void)
     m_settings.writeEntry("/PatchbayPath", sPatchbayPath);
     m_settings.endGroup();
 
+	// Save patchbay list...
+	m_settings.beginGroup("/Patchbays");
+	sPrefix = "/Patchbay%1";
+	i = 0;
+	for (QStringList::Iterator iter = patchbays.begin();
+			iter != patchbays.end(); ++iter)
+		m_settings.writeEntry(sPrefix.arg(++i), *iter);
+	// Cleanup old entries, if any...
+	for (++i; !m_settings.readEntry(sPrefix.arg(i)).isEmpty(); i++)
+		m_settings.removeEntry(sPrefix.arg(i));
+	m_settings.endGroup();
+
     m_settings.endGroup();
 }
 
@@ -248,7 +278,7 @@ bool qjackctlSetup::loadPreset ( qjackctlPreset& preset, const QString& sPreset
     preset.iWait        = m_settings.readNumEntry("/Wait", 21333);
     preset.iChan        = m_settings.readNumEntry("/Chan", 0);
     preset.sDriver      = m_settings.readEntry("/Driver", "alsa");
-    preset.sInterface   = m_settings.readEntry("/Interface", "hw:0");
+    preset.sInterface   = m_settings.readEntry("/Interface", QString::null);
     preset.iAudio       = m_settings.readNumEntry("/Audio", 0);
     preset.iDither      = m_settings.readNumEntry("/Dither", 0);
     preset.iTimeout     = m_settings.readNumEntry("/Timeout", 500);
@@ -495,6 +525,43 @@ void qjackctlSetup::saveComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 }
 
 
+//---------------------------------------------------------------------------
+// Splitter widget sizes persistence helper methods.
+
+void qjackctlSetup::loadSplitterSizes ( QSplitter *pSplitter )
+{
+	// Try to restore old splitter sizes...
+	if (pSplitter) {
+		m_settings.beginGroup("/Splitter/" + QString(pSplitter->name()));
+		QValueList<int> sizes;
+		QStringList list = m_settings.readListEntry("/sizes");
+		QStringList::Iterator iter = list.begin();
+		while (iter != list.end())
+		    sizes.append((*iter++).toInt());
+		if (!sizes.isEmpty())
+		    pSplitter->setSizes(sizes);
+        m_settings.endGroup();
+	}
+}
+
+
+void qjackctlSetup::saveSplitterSizes ( QSplitter *pSplitter )
+{
+    // Try to save current splitter sizes...
+    if (pSplitter) {
+        m_settings.beginGroup("/Splitter/" + QString(pSplitter->name()));
+        QStringList list;
+		QValueList<int> sizes = pSplitter->sizes();
+		QValueList<int>::Iterator iter = sizes.begin();
+		while (iter != sizes.end())
+		    list.append(QString::number(*iter++));
+		if (!list.isEmpty())
+	        m_settings.writeEntry("/sizes", list);
+        m_settings.endGroup();
+    }
+}
+
+
 //---------------------------------------------------------------------------
 // Widget geometry persistence helper methods.
 
@@ -540,6 +607,9 @@ void qjackctlSetup::saveWidgetGeometry ( QWidget *pWidget )
 }
 
 
+//---------------------------------------------------------------------------
+// Delayed setup option.
+
 // Delayed widget setup helper class.
 qjackctlDelayedSetup::qjackctlDelayedSetup ( QWidget *pWidget,
 	const QPoint& pos, const QSize& size, bool bVisible, int iDelay )
