@@ -22,10 +22,12 @@
 #ifndef __qjackctlSetup_h
 #define __qjackctlSetup_h
 
-#include <qcombobox.h>
-
 #include "qjackctlConnectAlias.h"
 
+#include <qcombobox.h>
+#include <qsplitter.h>
+
+
 // Audio mode combobox item indexes.
 #define QJACKCTL_DUPLEX     0
 #define QJACKCTL_CAPTURE    1
@@ -142,6 +144,8 @@ public:
 
     // Defaults...
     QString sPatchbayPath;
+    // Recent patchbay listing.
+    QStringList patchbays;
 
 	// Aliases containers.
 	qjackctlConnectAlias aliasJackOutputs;
@@ -163,6 +167,10 @@ public:
     void loadComboBoxHistory(QComboBox *pComboBox, int iLimit = 8);
     void saveComboBoxHistory(QComboBox *pComboBox, int iLimit = 8);
 
+	// Splitter widget sizes persistence helper methods.
+	void loadSplitterSizes(QSplitter *pSplitter);
+	void saveSplitterSizes(QSplitter *pSplitter);
+
     // Widget geometry persistence helper prototypes.
     void saveWidgetGeometry(QWidget *pWidget);
     void loadWidgetGeometry(QWidget *pWidget);
