@@ -20,14 +20,13 @@
 
 *****************************************************************************/
 
+#include "qjackctlAbout.h"
+#include "qjackctlConnectAlias.h"
+
 #include <qregexp.h>
 
 #include <stdlib.h>
 
-#include "config.h"
-
-#include "qjackctlConnectAlias.h"
-
 
 // Kind of constructor.
 void qjackctlSocketForm::init()
