@@ -20,11 +20,11 @@
 
 *****************************************************************************/
 
-#include "config.h"
-
+#include "qjackctlAbout.h"
 #include "qjackctlStatus.h"
 #include "qjackctlSetup.h"
 
+
 // Custom tooltip class.
 class qjackctlStatusToolTip : public QToolTip
 {
@@ -33,6 +33,8 @@ public:
 	// Constructor.
 	qjackctlStatusToolTip(QListView *pListView)
 		: QToolTip(pListView->viewport()) { m_pListView = pListView; }
+	// Virtual destructor.
+	virtual ~qjackctlStatusToolTip() {}
 
 protected:
 
