@@ -19,14 +19,13 @@
 
 *****************************************************************************/
 
+#include "qjackctlAbout.h"
 #include "qjackctlSystemTray.h"
 
 #include <qtooltip.h>
 #include <qbitmap.h>
 #include <qimage.h>
 
-#include "config.h"
-
 #ifdef CONFIG_SYSTEM_TRAY
 #include <X11/Xatom.h>
 #include <X11/Xlib.h>
